Examples
========

.. toctree::
   :maxdepth: 1

   BinaryExamples
   TernaryExamples
   Metastability
   ReferenceStateExamples
   EquilibriumWithOrdering
   CementiteAnalysis

Advanced Examples
=================

.. toctree::
   :maxdepth: 1

   UsingCalculationResults
   LegacyEnergySurface
   LegacyReferenceState
   ChargedPhases
   PlotActivity
   ViscosityModel
   Mapping
